pub struct Registration {
pub on_create: bool,
pub on_link: bool,
pub on_publish: bool,
}Expand description
Which events cause a document to be assigned (registered) an ID.
Fields
on_create: boolRegister every document at creation time (eager).
on_link: boolRegister when a document is first referenced by ID (e.g. a wikilink).
on_publish: boolRegister when a document is published.
Implementations
Sourceimpl Registration
impl Registration